From 0b0c614d4144c203f7ea0e26959f6368704c45b1 Mon Sep 17 00:00:00 2001
From: Takuma Fujiwara <t-fujiwara1@ti.com>
Date: Mon, 31 Jul 2023 15:39:42 -0500
Subject: [PATCH] Temporary workaround to disable kernel panic for pcie switch
 - errata i2086 for J721E/DRA829/TDA4VM. Also disables any other interrupts
 with ID 0xbf000000, so undefined behaviors will happen if hit outside the
 context of pcie initialization.

---
 arch/arm64/kernel/traps.c | 14 +++++++++++---
 1 file changed, 11 insertions(+), 3 deletions(-)

diff --git a/arch/arm64/kernel/traps.c b/arch/arm64/kernel/traps.c
index 2059d8f43..8a7e5e1dd 100644
--- a/arch/arm64/kernel/traps.c
+++ b/arch/arm64/kernel/traps.c
@@ -874,9 +874,17 @@ asmlinkage void noinstr do_serror(struct pt_regs *regs, unsigned int esr)
 {
 	arm64_enter_nmi(regs);
 
-	/* non-RAS errors are not containable */
-	if (!arm64_is_ras_serror(esr) || arm64_is_fatal_ras_serror(regs, esr))
-		arm64_serror_panic(regs, esr);
+	/* Temporary workaround to disable kernel panic for 
+	 * pcie switch - errata i2086 for J721E/DRA829/TDA4VM. 
+	 * Also disables any other interrupts with ID 0xbf000000,
+	 * so undefined behaviors will happen if hit outside the
+	 * context of pcie initialization.
+	 */
+	if (esr!=0xbf000000){ 
+		/* non-RAS errors are not containable */
+		if (!arm64_is_ras_serror(esr) || arm64_is_fatal_ras_serror(regs, esr))
+			arm64_serror_panic(regs, esr);
+	}
 
 	arm64_exit_nmi(regs);
 }
-- 
2.17.1

